#
# spec file for package bcm43xx-firmware
#
# Copyright (c) 2019 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           bcm43xx-firmware
Version:        20180314
Release:        lp152.10.3.1
Summary:        Firmware for the Broadcom/Cypress BCM43xx chipset family
License:        SUSE-Firmware
Group:          System/Kernel
URL:            https://community.cypress.com/community/linux
# From https://github.com/raspberrypi/linux/issues/1325#issuecomment-195560582
# Phil Elwell (Raspberry Pi Foundation) wrote: "Broadcom have said that
# the firmware files for the BCM43438 are covered under this licence:"
Source0:        https://git.kernel.org/cgit/linux/kernel/git/firmware/linux-firmware.git/plain/LICENCE.broadcom_bcm43xx
# The BCM43XXXX.hcd files are under this license
Source3:        https://git.kernel.org/pub/scm/linux/kernel/git/firmware/linux-firmware.git/plain/LICENCE.cypress
#BCM4329
Source291:      https://raw.githubusercontent.com/SolidRun/meta-solidrun-arm-imx6/fido/recipes-bsp/broadcom-nvram-config/files/solidrun-imx6/brcmfmac4329-sdio.txt#/brcmfmac4329-sdio.solidrun,cubox-i-dl.txt
#BCM4330
Source301:      https://raw.githubusercontent.com/SolidRun/meta-solidrun-arm-imx6/fido/recipes-bsp/broadcom-nvram-config/files/solidrun-imx6/brcmfmac4330-sdio.txt#/brcmfmac4330-sdio.solidrun,cubox-i-q.txt
#BCM4339
Source391:      brcmfmac4339-sdio.tronsmart,vega-s95-telos.txt
#BCM43362
Source3622:     https://github.com/Bananian/bananian/raw/master/deb/u-boot-m2-bananian_armhf/lib/firmware/brcm/brcmfmac43362-sdio.txt#/brcmfmac43362-sdio.sinovoip,bpi-m2.txt
#BCM43430
Source4309:     https://github.com/RPi-Distro/bluez-firmware/raw/master/broadcom/BCM43430A1.hcd
#brcmfmac4356-pcie.txt is taken from ChromeOS repo
# https://chromium.googlesource.com/chromiumos/third_party/linux-firmware/+/f151f016b4fe656399f199e28cabf8d658bcb52b/brcm/brcmfmac4356-pcie.txt
Source4356:     brcmfmac4356-pcie.txt
Source4559:     https://github.com/RPi-Distro/bluez-firmware/raw/master/broadcom/BCM4345C0.hcd
# Owns /lib/firmware/brcm and potentially conflicts
BuildRequires:  kernel-firmware
# Owns /etc/modprobe.d
BuildRequires:  suse-module-tools
Requires:       kernel-firmware
# BCM4356 PCI
Supplements:    modalias(pci:v000014E4d000043ECsv*sd*bc*sc*i*)
# Raspberry Pi 3 Model B
Supplements:    modalias(sdio:c*v02D0dA9A6*)
BuildArch:      noarch

%description
This package provides the firmware files needed for the
Broadcom (now Cypress) BCM43430 Wifi+Bluetooth chipset
as well as NVRAM config files for BCM43362, BCM43430 and
further related chipsets.

%prep
%setup -q -c -T
cp %{SOURCE0} %{SOURCE3} .

%build

%install
# Used by brcmfmac
mkdir -p %{buildroot}/lib/firmware/brcm
install -c -m 0644 %{SOURCE291} %{buildroot}/lib/firmware/brcm/
install -c -m 0644 %{SOURCE301} %{buildroot}/lib/firmware/brcm/
install -c -m 0644 %{SOURCE391} %{buildroot}/lib/firmware/brcm/
install -c -m 0644 %{SOURCE3622} %{buildroot}/lib/firmware/brcm/
install -c -m 0644 %{SOURCE4356} %{buildroot}/lib/firmware/brcm/
# Used by bluez (hciattach)
install -c -m 0644 %{SOURCE4309} %{buildroot}/lib/firmware/
install -c -m 0644 %{SOURCE4559} %{buildroot}/lib/firmware/

%files
%license LICENCE.broadcom_bcm43xx LICENCE.cypress
/lib/firmware/BCM43430A1.hcd
/lib/firmware/BCM4345C0.hcd
/lib/firmware/brcm/brcmfmac4329-sdio.solidrun,cubox-i-dl.txt
/lib/firmware/brcm/brcmfmac4330-sdio.solidrun,cubox-i-q.txt
/lib/firmware/brcm/brcmfmac4339-sdio.tronsmart,vega-s95-telos.txt
/lib/firmware/brcm/brcmfmac43362-sdio.sinovoip,bpi-m2.txt
/lib/firmware/brcm/brcmfmac4356-pcie.txt

%changelog
* Wed Sep 16 2020 Matthias Brugger <mbrugger@suse.com>
- Update bluetooth firmware to address Sweyntooth and Spectra issues (bsc#1176631):
  * BCM43430A1.hcd
  * BCM4345C0.hcd
- Remove wildcards in %%files
- Delete brcmfmac43362-sdio-cubietruck.txt as now part of kernel-firmware (as brcmfmac43362-sdio.cubietech,cubietruck.txt)
- brcmfmac driver loads file depending on compatible. Rename files correspondingly. (bsc#1169094)
  * brcmfmac4329-sdio-cubox-i.txt -> brcmfmac4329-sdio.solidrun,cubox-i-dl.txt
  * brcmfmac4330-sdio-cubox-i.txt -> brcmfmac4330-sdio.solidrun,cubox-i-q.txt
  * brcmfmac4339-sdio-vega-s95-telos.txt -> brcmfmac4339-sdio.tronsmart,vega-s95-telos.txt
  * brcmfmac43362-sdio-bananapi-m2.txt -> brcmfmac43362-sdio.sinovoip,bpi-m2.txt
- delete modprobe config file and install-brcmfmac.sh as no longer needed
* Wed Feb 19 2020 Nicolas Patricio Saenz Julienne <nsaenzjulienne@suse.com>
- Remove brcmfmac43455-sdio.raspberrypi,4-model-b.txt, already available in
  kernel-firmware (bsc#1163237)
* Wed Nov 27 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update boardflags3 value for brcmfmac43455-sdio.raspberrypi,4-model-b.txt
  to fix WiFi connection on RPi4
* Wed Oct  2 2019 Matthias Brugger <mbrugger@suse.com>
- Add brcmfmac43455-sdio.raspberrypi,4-model-b.txt
* Thu Jan 24 2019 Matthias Brugger <mbrugger@suse.com>
- Remove files that are now present in kernel-firmware (fate#326215).
- Delete softlink creation for this files. (bsc#1098041).
* Thu Aug 30 2018 fvogt@suse.com
- Add bluetooth firmware for RPi 3 B+ (bsc#1103587)
- Update brcmfmac43430-sdio.txt and brcmfmac43455-sdio.txt:
  * Improved brcmfmac BT coexistence parameters
- Switch BCM43430A1.hcd to official source:
  * No changelog available
- Use %%license
- Run spec-cleaner
* Tue Jun 26 2018 tiwai@suse.de
- Add brcmfmac4356-pcie.txt for BCM 4356 PCI (bsc#1099149)
* Wed Mar 14 2018 agraf@suse.com
- Add support for RPi 3 B+ (bcm43455, bsc#1085262)
* Mon Jun 12 2017 afaerber@suse.de
- Add Supplements for Raspberry Pi 3 (bsc#1041823)
- Resolve NUL char warning on modprobe for Tumbleweed by properly
  iterating over zero-separated DT compatible strings
* Mon Apr 10 2017 afaerber@suse.de
- Require kernel-firmware, suggested by fvogt. (bsc#1033137)
  Don't require version 20161005 or later, to remain compatible
  with older distributions.
- Bump version to today's date. This will allow other packages
  such as kernel-firmware to conflict against our older version.
* Sun Jan 15 2017 afaerber@suse.de
- Add brcmfmac4339-sdio-vega-s95-telos.txt
* Sun Jan  8 2017 afaerber@suse.de
- Add vendor prefix for CuBox-i compatible string
- Reorder by board name
* Tue Jan  3 2017 tbechtold@suse.com
- Add brcmfmac4329-sdio-cubox-i.txt and brcmfmac4330-sdio-cubox-i.txt.
* Tue Oct 18 2016 afaerber@suse.de
- Dropped brcmfmac43430-sdio.bin (in kernel-firmware now)
* Wed Sep  7 2016 afaerber@suse.de
- Move %%post script to install-brcmfmac.sh, add 50-brcmfmac.conf.
  This avoids workarounds for Kiwi images. (tiwai)
* Sat Sep  3 2016 afaerber@suse.de
- Renamed package from bcm43430-firmware to bcm43xx-firmware (duwe)
- Renamed brcmfmac43430-sdio.txt to brcmfmac43430-sdio-rpi3.txt and
  added post-install script to symlink
  * Added brcmfmac43362-sdio-{cubietruck,bananapi-{m1+,m2}}.txt
* Tue Aug 30 2016 afaerber@suse.de
- Renamed package from brcm43430-firmware to bcm43430-firmware
* Mon Aug 29 2016 fvogt@suse.com
- Make Source: URLs absolute
- Update brcmfmac43430-sdio.bin to 7.45.41.26
* Thu Aug 25 2016 fvogt@suse.com
- Add initial package
